#!/usr/bin/env python3
import os
import sys

from OpenFont import FontSpecificNameID, NameID, NameTable_Format_0, OpenFontFile, PredefinedNameID, TrueTypeOutlines, open_font_file

def search_names(font: OpenFontFile, nameID: NameID) -> str:
	assert isinstance(font.naming_table, NameTable_Format_0)

	for nameRecord in font.naming_table.nameRecord:
		if nameRecord.nameID == nameID:
			return nameRecord.string
	
	assert False, f"Name not found: {nameID}"

def print_font(font: OpenFontFile):
	assert isinstance(font.naming_table, NameTable_Format_0)
	assert isinstance(font.outlines, TrueTypeOutlines)

	name = search_names(font, PredefinedNameID.FULL_NAME)

	print(name, f"({font.maximum_profile.numGlyphs} glyphs, {font.naming_table.count} names)")
	if font.font_variations:
		axis_names = [search_names(font, FontSpecificNameID(axis.axisNameID)) for axis in font.font_variations.font_variations.axes]
		num_instances = font.font_variations.font_variations.instanceCount
		print(f"\tAxes: [{', '.join(axis_names)}] ({num_instances} instances)")


def do_font(file: str):
	try:
		font = open_font_file(file)
		print_font(font)
	except AssertionError as err:
		print(f"Failed: {file}")
		raise err
	
assert not sys.stdin.isatty()
for line in sys.stdin:
	file = line.rstrip('\n')
	do_font(file)